from setuptools import setup


setup(
    name='kagiso_django_auth',
    version='0.1',
    author='Kagiso Media',
    author_email='development@kagiso.io',
    url='https://github.com/Kagiso-Future-Media/django_auth',
    install_requires=[
            'jsonfield==1.0.3',
            'requests==2.6.0',
    ],
)
